@@ -1,4 +1,8 @@
 integerCols <- function(data) {
+  # version 1.1 (2 May 2022)
+  
+  data <- as.data.frame(data)
+  
   is.wholenumber <- function(x, tol = .Machine$double.eps ^ 0.5) {
     abs(x - round(x)) < tol
   }  # from ?is.integer examples
